# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ADD_NOISE_TO_IMAGE_METADATA = Metadata(
    id="5da8ee75f74c156a91ae2c476ce7533d884a9bda.boutiques",
    name="AddNoiseToImage",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


AddNoiseToImageParameters = typing.TypedDict('AddNoiseToImageParameters', {
    "__STYX_TYPE__": typing.Literal["AddNoiseToImage"],
    "image_dimensionality": typing.NotRequired[typing.Literal[2, 3, 4] | None],
    "input_image": InputPathType,
    "noise_model": typing.Literal["AdditiveGaussian", "SaltAndPepper", "Shot", "Speckle"],
    "output": str,
    "verbose": typing.NotRequired[typing.Literal[0, 1] | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "AddNoiseToImage": add_noise_to_image_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "AddNoiseToImage": add_noise_to_image_outputs,
    }.get(t)


class AddNoiseToImageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `add_noise_to_image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    noise_corrupted_image: OutputPathType
    """The output is the noise corrupted version of the input image."""


def add_noise_to_image_params(
    input_image: InputPathType,
    noise_model: typing.Literal["AdditiveGaussian", "SaltAndPepper", "Shot", "Speckle"],
    output: str,
    image_dimensionality: typing.Literal[2, 3, 4] | None = None,
    verbose: typing.Literal[0, 1] | None = None,
) -> AddNoiseToImageParameters:
    """
    Build parameters.
    
    Args:
        input_image: A scalar image is expected as input for noise correction.
        noise_model: Use different noise models each with its own (default)\
            parameters.
        output: The output consists of the noise corrupted version of the input\
            image.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, the program tries to\
            infer the dimensionality from the input image.
        verbose: Verbose output.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "AddNoiseToImage",
        "input_image": input_image,
        "noise_model": noise_model,
        "output": output,
    }
    if image_dimensionality is not None:
        params["image_dimensionality"] = image_dimensionality
    if verbose is not None:
        params["verbose"] = verbose
    return params


def add_noise_to_image_cargs(
    params: AddNoiseToImageParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("AddNoiseToImage")
    if params.get("image_dimensionality") is not None:
        cargs.extend([
            "--image-dimensionality",
            str(params.get("image_dimensionality"))
        ])
    cargs.extend([
        "--input-image",
        execution.input_file(params.get("input_image"))
    ])
    cargs.extend([
        "--noise-model",
        params.get("noise_model")
    ])
    cargs.extend([
        "--output",
        params.get("output")
    ])
    if params.get("verbose") is not None:
        cargs.extend([
            "--verbose",
            str(params.get("verbose"))
        ])
    return cargs


def add_noise_to_image_outputs(
    params: AddNoiseToImageParameters,
    execution: Execution,
) -> AddNoiseToImageOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AddNoiseToImageOutputs(
        root=execution.output_file("."),
        noise_corrupted_image=execution.output_file(params.get("output")),
    )
    return ret


def add_noise_to_image_execute(
    params: AddNoiseToImageParameters,
    execution: Execution,
) -> AddNoiseToImageOutputs:
    """
    Add various types of noise to an image.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `AddNoiseToImageOutputs`).
    """
    params = execution.params(params)
    cargs = add_noise_to_image_cargs(params, execution)
    ret = add_noise_to_image_outputs(params, execution)
    execution.run(cargs)
    return ret


def add_noise_to_image(
    input_image: InputPathType,
    noise_model: typing.Literal["AdditiveGaussian", "SaltAndPepper", "Shot", "Speckle"],
    output: str,
    image_dimensionality: typing.Literal[2, 3, 4] | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> AddNoiseToImageOutputs:
    """
    Add various types of noise to an image.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_image: A scalar image is expected as input for noise correction.
        noise_model: Use different noise models each with its own (default)\
            parameters.
        output: The output consists of the noise corrupted version of the input\
            image.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, the program tries to\
            infer the dimensionality from the input image.
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AddNoiseToImageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADD_NOISE_TO_IMAGE_METADATA)
    params = add_noise_to_image_params(
        image_dimensionality=image_dimensionality,
        input_image=input_image,
        noise_model=noise_model,
        output=output,
        verbose=verbose,
    )
    return add_noise_to_image_execute(params, execution)


__all__ = [
    "ADD_NOISE_TO_IMAGE_METADATA",
    "AddNoiseToImageOutputs",
    "AddNoiseToImageParameters",
    "add_noise_to_image",
    "add_noise_to_image_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

PRINT_HEADER_METADATA = Metadata(
    id="514e4dbae6f3b5a425925fca62d2ade89ff0b0c2.boutiques",
    name="PrintHeader",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


PrintHeaderParameters = typing.TypedDict('PrintHeaderParameters', {
    "__STYX_TYPE__": typing.Literal["PrintHeader"],
    "image": InputPathType,
    "what_information": typing.NotRequired[typing.Literal[0, 1, 2, 3, 4] | None],
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "PrintHeader": print_header_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "PrintHeader": print_header_outputs,
    }.get(t)


class PrintHeaderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `print_header(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """The printed header information from the specified image."""


def print_header_params(
    image: InputPathType,
    what_information: typing.Literal[0, 1, 2, 3, 4] | None = None,
) -> PrintHeaderParameters:
    """
    Build parameters.
    
    Args:
        image: The image file to extract header information from. Supported\
            extension: .ext.
        what_information: Specify the type of information to print: 0 for\
            origin, 1 for spacing, 2 for size, 3 for index, 4 for direction.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "PrintHeader",
        "image": image,
    }
    if what_information is not None:
        params["what_information"] = what_information
    return params


def print_header_cargs(
    params: PrintHeaderParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("PrintHeader")
    cargs.append(execution.input_file(params.get("image")))
    if params.get("what_information") is not None:
        cargs.append(str(params.get("what_information")))
    return cargs


def print_header_outputs(
    params: PrintHeaderParameters,
    execution: Execution,
) -> PrintHeaderOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = PrintHeaderOutputs(
        root=execution.output_file("."),
        output=execution.output_file("header_info.txt"),
    )
    return ret


def print_header_execute(
    params: PrintHeaderParameters,
    execution: Execution,
) -> PrintHeaderOutputs:
    """
    A utility to print header information from an image file.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `PrintHeaderOutputs`).
    """
    params = execution.params(params)
    cargs = print_header_cargs(params, execution)
    ret = print_header_outputs(params, execution)
    execution.run(cargs)
    return ret


def print_header(
    image: InputPathType,
    what_information: typing.Literal[0, 1, 2, 3, 4] | None = None,
    runner: Runner | None = None,
) -> PrintHeaderOutputs:
    """
    A utility to print header information from an image file.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image: The image file to extract header information from. Supported\
            extension: .ext.
        what_information: Specify the type of information to print: 0 for\
            origin, 1 for spacing, 2 for size, 3 for index, 4 for direction.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PrintHeaderOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PRINT_HEADER_METADATA)
    params = print_header_params(
        image=image,
        what_information=what_information,
    )
    return print_header_execute(params, execution)


__all__ = [
    "PRINT_HEADER_METADATA",
    "PrintHeaderOutputs",
    "PrintHeaderParameters",
    "print_header",
    "print_header_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CREATE_DISPLACEMENT_FIELD_METADATA = Metadata(
    id="4dbaa9ddf35cec6b6f78e7c9efdb17f6f5f6d1e2.boutiques",
    name="CreateDisplacementField",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


CreateDisplacementFieldParameters = typing.TypedDict('CreateDisplacementFieldParameters', {
    "__STYX_TYPE__": typing.Literal["CreateDisplacementField"],
    "image_dimension": int,
    "enforce_zero_boundary_flag": typing.Literal[0, 1],
    "component_images": list[InputPathType],
    "output_image": str,
})


def dyn_cargs(
    t: str,
) -> typing.Any:
    """
    Get build cargs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build cargs function.
    """
    return {
        "CreateDisplacementField": create_displacement_field_cargs,
    }.get(t)


def dyn_outputs(
    t: str,
) -> typing.Any:
    """
    Get build outputs function by command type.
    
    Args:
        t: Command type.
    Returns:
        Build outputs function.
    """
    return {
        "CreateDisplacementField": create_displacement_field_outputs,
    }.get(t)


class CreateDisplacementFieldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `create_displacement_field(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_displacement_field: OutputPathType
    """The generated itkImage of itkVector pixels representing the displacement
    field."""


def create_displacement_field_params(
    image_dimension: int,
    enforce_zero_boundary_flag: typing.Literal[0, 1],
    component_images: list[InputPathType],
    output_image: str,
) -> CreateDisplacementFieldParameters:
    """
    Build parameters.
    
    Args:
        image_dimension: The dimension of the image, typically 2 or 3.
        enforce_zero_boundary_flag: Create zero-valued vectors along the\
            borders when enabled (pass 1), recommended for better displacement\
            field behavior.
        component_images: Input component images, each used for a vector\
            component. All component images must have the same size, offset,\
            origin, and spacing.
        output_image: The output displacement field image with itkVector\
            pixels.
    Returns:
        Parameter dictionary
    """
    params = {
        "__STYXTYPE__": "CreateDisplacementField",
        "image_dimension": image_dimension,
        "enforce_zero_boundary_flag": enforce_zero_boundary_flag,
        "component_images": component_images,
        "output_image": output_image,
    }
    return params


def create_displacement_field_cargs(
    params: CreateDisplacementFieldParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("CreateDisplacementField")
    cargs.append(str(params.get("image_dimension")))
    cargs.append(str(params.get("enforce_zero_boundary_flag")))
    cargs.extend([execution.input_file(f) for f in params.get("component_images")])
    cargs.append(params.get("output_image"))
    return cargs


def create_displacement_field_outputs(
    params: CreateDisplacementFieldParameters,
    execution: Execution,
) -> CreateDisplacementFieldOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CreateDisplacementFieldOutputs(
        root=execution.output_file("."),
        output_displacement_field=execution.output_file(params.get("output_image")),
    )
    return ret


def create_displacement_field_execute(
    params: CreateDisplacementFieldParameters,
    execution: Execution,
) -> CreateDisplacementFieldOutputs:
    """
    Create an itkImage of itkVector pixels (NOT an itkVectorImage), using each
    scalar input component image for each vector component. An itkImage of
    itkVectors is the standard type for displacement fields in ITK. All component
    images (up to 8) are assumed to have the same size, offset, origin, and spacing.
    The 'EnforceZeroBoundaryFlag' option will create zero-valued vectors along the
    borders when enabled (pass 1), and is recommended for better displacement field
    behavior.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        params: The parameters.
        execution: The execution object.
    Returns:
        NamedTuple of outputs (described in `CreateDisplacementFieldOutputs`).
    """
    params = execution.params(params)
    cargs = create_displacement_field_cargs(params, execution)
    ret = create_displacement_field_outputs(params, execution)
    execution.run(cargs)
    return ret


def create_displacement_field(
    image_dimension: int,
    enforce_zero_boundary_flag: typing.Literal[0, 1],
    component_images: list[InputPathType],
    output_image: str,
    runner: Runner | None = None,
) -> CreateDisplacementFieldOutputs:
    """
    Create an itkImage of itkVector pixels (NOT an itkVectorImage), using each
    scalar input component image for each vector component. An itkImage of
    itkVectors is the standard type for displacement fields in ITK. All component
    images (up to 8) are assumed to have the same size, offset, origin, and spacing.
    The 'EnforceZeroBoundaryFlag' option will create zero-valued vectors along the
    borders when enabled (pass 1), and is recommended for better displacement field
    behavior.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimension of the image, typically 2 or 3.
        enforce_zero_boundary_flag: Create zero-valued vectors along the\
            borders when enabled (pass 1), recommended for better displacement\
            field behavior.
        component_images: Input component images, each used for a vector\
            component. All component images must have the same size, offset,\
            origin, and spacing.
        output_image: The output displacement field image with itkVector\
            pixels.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CreateDisplacementFieldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CREATE_DISPLACEMENT_FIELD_METADATA)
    params = create_displacement_field_params(
        image_dimension=image_dimension,
        enforce_zero_boundary_flag=enforce_zero_boundary_flag,
        component_images=component_images,
        output_image=output_image,
    )
    return create_displacement_field_execute(params, execution)


__all__ = [
    "CREATE_DISPLACEMENT_FIELD_METADATA",
    "CreateDisplacementFieldOutputs",
    "CreateDisplacementFieldParameters",
    "create_displacement_field",
    "create_displacement_field_params",
]
